<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "編集フォームの受信者");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "編集フォームの受信者");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "フォームページ");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "あなたは、カンマでメールを分離することにより、複数の受信者を設定することができます。");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "受信者を保存しています...");
define('VIEW_FORM_TABLES_HEADING', "フォームテーブルを表示する");
define('VIEW_FORM_TABLES_BTN', "フォームテーブルを表示する");
define('VIEW_FORM_TABLES_SELECT_TABLE', "表示する表を選択する");
define('VIEW_FORM_TABLES_FILTER_READ', "フィルタ読取りメッセージ");
?>